pub struct LabelRegistryBuilder { /* private fields */ }Expand description
Builder for creating a LabelRegistry with labelers.
This uses a builder pattern to ensure labelers are properly initialized before the registry is used.
Example
use std::sync::Arc;
use treetop_core::{LabelRegistryBuilder, RegexLabeler};
use regex::Regex;
let registry = LabelRegistryBuilder::new()
.add_labeler(Arc::new(RegexLabeler::new(
"Host",
"name",
"nameLabels",
vec![("prod".to_string(), Regex::new(r"\.prod\.").unwrap())],
)))
.build();Implementations
Sourceimpl LabelRegistryBuilder
impl LabelRegistryBuilder
Sourcepub fn add_labeler(self, labeler: Arc<dyn Labeler>) -> Self
pub fn add_labeler(self, labeler: Arc<dyn Labeler>) -> Self
Add a labeler to the registry.
This can be called repeatedly to build up a registry before build().
Sourcepub fn build(self) -> LabelRegistry
pub fn build(self) -> LabelRegistry
Build the label registry.
Consumes the builder and returns an initialized registry ready to use
with PolicyEngine::with_label_registry().