pub struct PolicyStoreConfig { /* private fields */ }Expand description
One declared policy store and the Cedar namespace subtree it owns.
Implementations
Sourceimpl PolicyStoreConfig
impl PolicyStoreConfig
Sourcepub fn new(
id: impl AsRef<str>,
namespace: impl AsRef<str>,
) -> Result<Self, PolicyError>
pub fn new( id: impl AsRef<str>, namespace: impl AsRef<str>, ) -> Result<Self, PolicyError>
Declare a store whose requests and ordinary policies use namespace.
The namespace is a Cedar-qualified name such as ExampleCo::DNS. The
store also owns nested namespaces such as ExampleCo::DNS::Admin.
Sourcepub fn id(&self) -> &PolicyStoreId
pub fn id(&self) -> &PolicyStoreId
Return the stable store identifier.